PhysicalDeviceProperties

Struct PhysicalDeviceProperties 

pub struct PhysicalDeviceProperties {
    pub limits: Limits,
    pub descriptor_indexing: DescriptorIndexingProperties,
    pub mesh_shader: MeshShaderProperties,
    pub sampler_reduction: SamplerReductionProperties,
    pub downlevel: DownlevelProperties,
    pub performance_caveats: PerformanceCaveats,
    pub dynamic_pipeline_states: DynamicStates,
    pub external_memory_limits: ExternalMemoryLimits,
}
Properties of physical devices that are exposed but do not need to be explicitly opted into.

This contains things like resource limits, alignment requirements, and finer-grained feature capabilities.

Fields

limits: Limits

Core limits.

descriptor_indexing: DescriptorIndexingProperties

Descriptor Indexing properties.

mesh_shader: MeshShaderProperties

Mesh Shader properties.

sampler_reduction: SamplerReductionProperties

Sampler reduction modes.

downlevel: DownlevelProperties

Downlevel properties.

performance_caveats: PerformanceCaveats

Performance caveats.

dynamic_pipeline_states: DynamicStates

Dynamic pipeline states.

external_memory_limits: ExternalMemoryLimits

External memory limits